@@ -1,37 +1,34 @@
 package Acme::CPANAuthors::Israeli;
-
+$Acme::CPANAuthors::Israeli::VERSION = '0.0400';
 use warnings;
 use strict;
 
 
-our $VERSION = '0.0310';
-
 use Acme::CPANAuthors::Register (
-    AMOSS => 'Amos Shapira',
-    EILARA => 'Ran Eilam',
-    FELIXL => 'Felix Liberman',
-    GENIE => 'Goldin Evgeny',
-    ISAAC => 'Issac Goldstand',
-    MIGO => 'Mikhael Goikhman',
-    NUFFIN => 'Yuval Kogman',
-    PETERG => 'Peter Gordon',
+    AMOSS     => 'Amos Shapira',
+    EILARA    => 'Ran Eilam',
+    FELIXL    => 'Felix Liberman',
+    GENIE     => 'Goldin Evgeny',
+    ISAAC     => 'Issac Goldstand',
+    MIGO      => 'Mikhael Goikhman',
+    NUFFIN    => 'Yuval Kogman',
+    PETERG    => 'Peter Gordon',
     PRILUSKYJ => 'Jaime Prilusky',
-    RAZINF => 'Oded S. Resnik',
-    REUVEN => 'Reuven M. Lerner',
-    ROMM => 'Roman Parparov',
-    SEMUELF => 'Shmuel Fomberg',
-    SHLOMIF => 'Shlomi Fish',
-    SHLOMOY => 'Shlomo Yona',
+    RAZINF    => 'Oded S. Resnik',
+    REUVEN    => 'Reuven M. Lerner',
+    ROMM      => 'Roman Parparov',
+    SEMUELF   => 'Shmuel Fomberg',
+    SHLOMIF   => 'Shlomi Fish',
+    SHLOMOY   => 'Shlomo Yona',
     SMALYSHEV => 'Stanislav Malyshev',
-    SZABGAB => 'Gabor Szabo',
-    YOSEFM => 'Yosef Meller',
-    SCHOP => 'Ariel Brosh (R.I.P.)',
+    SZABGAB   => 'Gabor Szabo',
+    YOSEFM    => 'Yosef Meller',
+    SCHOP     => 'Ariel Brosh (R.I.P.)',
 );
 
 
 
-
-1; # End of Acme::CPANAuthors::Israeli
+1;    # End of Acme::CPANAuthors::Israeli
 
 __END__
 
@@ -45,7 +42,7 @@ Acme::CPANAuthors::Israeli - We are Israeli CPAN Authors
 
 =head1 VERSION
 
-version 0.0310
+version 0.0400
 
 =head1 SYNOPSIS
 
@@ -72,38 +69,10 @@ me.
 
 L<Acme::CPANAuthors> - the driver for this class.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is Copyright (c) 2008 by Shlomi Fish.
-
-This is free software, licensed under:
-
-  The MIT (X11) License
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-CPANAuthors-Israeli or by
-email to bug-acme-cpanauthors-israeli @rt.cpan.org.
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc Acme::CPANAuthors::Israeli
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -117,15 +86,7 @@ MetaCPAN
 
 A modern, open-source CPAN search engine, useful to view POD in HTML format.
 
-L<http://metacpan.org/release/Acme-CPANAuthors-Israeli>
-
-=item *
-
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/Acme-CPANAuthors-Israeli>
+L<https://metacpan.org/release/Acme-CPANAuthors-Israeli>
 
 =item *
 
@@ -133,31 +94,7 @@ RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Acme-CPANAuthors-Israeli>
-
-=item *
-
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/Acme-CPANAuthors-Israeli>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/Acme-CPANAuthors-Israeli>
-
-=item *
-
-CPAN Forum
-
-The CPAN Forum is a web forum for discussing Perl modules.
-
-L<http://cpanforum.com/dist/Acme-CPANAuthors-Israeli>
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=Acme-CPANAuthors-Israeli>
 
 =item *
 
@@ -165,13 +102,13 @@ CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
 
-L<http://cpants.perl.org/dist/overview/Acme-CPANAuthors-Israeli>
+L<http://cpants.cpanauthors.org/dist/Acme-CPANAuthors-Israeli>
 
 =item *
 
 CPAN Testers
 
-The CPAN Testers is a network of smokers who run automated tests on uploaded CPAN distributions.
+The CPAN Testers is a network of smoke testers who run automated tests on uploaded CPAN distributions.
 
 L<http://www.cpantesters.org/distro/A/Acme-CPANAuthors-Israeli>
 
@@ -196,7 +133,7 @@ L<http://deps.cpantesters.org/?module=Acme::CPANAuthors::Israeli>
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests by email to C<bug-acme-cpanauthors-israeli at rt.cpan.org>, or through
-the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Acme-CPANAuthors-Israeli>. You will be automatically notified of any
+the web interface at L<https://rt.cpan.org/Public/Bug/Report.html?Queue=Acme-CPANAuthors-Israeli>. You will be automatically notified of any
 progress on the request by the system.
 
 =head2 Source Code
@@ -205,8 +142,29 @@ The code is open to the world, and available for you to hack on. Please feel fre
 with it, or whatever. If you want to contribute patches, please send me a diff or prod me to pull
 from your repository :)
 
-L<http://github.com/shlomif/perl-Acme-CPANAuthors-Israeli>
+L<https://github.com/shlomif/perl-Acme-CPANAuthors-Israeli>
 
-  git clone http://github.com/shlomif/perl-Acme-CPANAuthors-Israeli
+  git clone git://github.com/shlomif/perl-Acme-CPANAuthors-Israeli.git
+
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-Acme-CPANAuthors-Israeli/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2008 by Shlomi Fish.
+
+This is free software, licensed under:
+
+  The MIT (X11) License
 
 =cut
